/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * $Id$
 */
package com.kvisco.xpath;

import java.util.Hashtable;

import org.w3c.dom.*;

/**
 * Represents an Addition Expr. 
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
 * @version $Revision$ $Date$
**/
public class AdditionExpr extends BinaryExpr {

    
    
      //---------------/
     //- Constructor -/
    //---------------/
    
    /**
     * Creates a new Addition expression
     * @param leftSideExpr the Expr that is to be evaluated as
     * the left side of this AdditiveExpr
     * @param rightSideExpr the Expr that is to be evaluated as
     * the right side of this AdditiveExpr
    **/
    public AdditionExpr(Expr leftSideExpr, Expr rightSideExpr) {
        super(leftSideExpr, rightSideExpr);
    } //-- AdditionExpr 
    
      //------------------/
     //- Public Methods -/
    //------------------/
    
    /**
     * Returns the type of Expr this Expr represents
     * @return the type of Expr this Expr represents
    **/
    public short getExprType() {
        return Expr.NUMBER;
    } //-- getExprType
    
    /**
     * Evaluates this Expr using the given context Node and ExprContext
     * @param context the current context Node
     * @param contextInfo provides a way to retrieve additional context 
     * information needed to evaluate some expressions
     * @return the ExprResult
    **/
    public ExprResult evaluate(Node context, ExprContext contextInfo) 
        throws InvalidExprException
    {
        Expr leftExpr = getLeftSide();
        Expr rightExpr = getRightSide();
        
        if ((leftExpr == null) || (rightExpr == null))
            return new NumberResult(Double.NaN);

        ExprResult rResult = null;
        ExprResult lResult = null;
            
        rResult = rightExpr.evaluate(context, contextInfo);
        
        lResult = leftExpr.evaluate(context, contextInfo);
        
        return new NumberResult(lResult.numberValue()+rResult.numberValue());
    } //-- evaluate
    
    /**
     * Returns the String representation of this Expr
     * @return the String representation of this Expr
    **/
    public String toString() {
        
        
        StringBuffer sb = new StringBuffer();
        Expr expr = getLeftSide();
        
        if (expr != null)
            sb.append(expr.toString());
        else
            sb.append("null");
        sb.append(" + ");
        
        expr = getRightSide();
        
        if (expr != null)
            sb.append(expr.toString());
        else 
            sb.append("null");
        
        return sb.toString();
    } //-- toString
    
} //-- AdditionExpr