/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * $Id$ 
 */

package com.kvisco.xpath;

import com.kvisco.xpath.functions.FalseFunctionCall;
import com.kvisco.xpath.functions.TrueFunctionCall;

import org.w3c.dom.*;

/**
 * This class represents a BooleanExpr
 * <PRE>
 * [24] BooleanExpr ::= AndExpr | OrExpr | PrimaryExpr
 * </PRE>
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
 * @version $Revision$ $Date$
**/
public class BooleanExpr implements Expr {


    
    private Expr expr;
    
    
    
      //----------------/
     //- Constructors -/
    //----------------/

    /**
     * Creates a new BooleanExpr of the given type
    **/
    public BooleanExpr() {
        this(null);
    } //-- BooleanExpr

    public BooleanExpr(boolean bool) {
        if (bool) this.expr = new TrueFunctionCall();
        else this.expr = new FalseFunctionCall();
    } //-- BooleanExpr
    
    /**
     * Creates a new BooleanExpr of the given type
     * and adds the given BooleanPrimaryExpr to the
     * expression list
    **/
    public BooleanExpr(Expr expr) {
        this.expr = expr;
    } //-- BooleanExpr
    
      //------------------/
     //- Public Methods -/
    //------------------/
    /**
     * Returns the type of Expr this Expr represents
     * @return the type of Expr this Expr represents
    **/
    public short getExprType() {
        return Expr.BOOLEAN;
    } //-- getExprType
    
    /**
     * Evaluates this Expr using the given context Node and ExprContext
     * @param context the current context Node
     * @param exprContext the ExprContext which has additional
     * information sometimes needed for evaluating XPath expressions
     * environment
     * @return the ExprResult
     * @exception InvalidExprException when an invalid expression is
     * encountered during evaluation
    **/
    public ExprResult evaluate(Node context, ExprContext exprContext)
        throws InvalidExprException
    {
        if (expr != null)
            return new BooleanResult(expr.evaluate(context, exprContext));
        else
            return new BooleanResult();
    } //-- evaluate
    
    /**
     * Returns the String representation of this BooleanExpr
     * @return the String representation of this BooleanExpr
    **/
    public String toString() {
        if (expr!= null) return expr.toString();
        else return "false()";
    } //-- toString
    
} //-- BooleanExpr
