/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * $Id$
 */

package com.kvisco.xpath;

import org.w3c.dom.*;

/**
 * Represents a comment() expression
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
 * @version $Revision$ $Date$
**/
public class CommentExpr implements NodeExpr {

      //----------------/
     //- Constructors -/
    //----------------/

    public CommentExpr() {
        super();
    } //-- CommentExpr

      //------------------/
     //- Public Methods -/
    //------------------/


    /**
     * Returns the String representation of this Expr
    **/
    public String toString() {
        return "comment()";
    } //-- toString

    /**
     * Evaluates this Expr using the given context Node and ExprContext
     * @param context the current context Node
     * @param exprContext the ExprContext which has additional
     * information sometimes needed for evaluating XPath expressions
     * @return the ExprResult
     * @exception InvalidExprException when an invalid expression is
     * encountered during evaluation
    **/
    public ExprResult evaluate(Node context, ExprContext exprContext)
        throws InvalidExprException
    {
        NodeSet nodeSet = new NodeSet();
        if (context == null) return nodeSet;

        NodeList nl = context.getChildNodes();
        for (int i = 0; i < nl.getLength(); i++) {
            Node node = nl.item(i);
            if (node.getNodeType() == Node.COMMENT_NODE) nodeSet.add(node);
        }
        return nodeSet;
    } //-- evaluate

    /**
     * Returns the type of this Expr
    **/
    public short getExprType() { return Expr.NODE_SET; }


    /**
     * Returns the type of this NodeExpr
     * @return the type of this NodeExpr
    **/
    public short getNodeExprType() { return NodeExpr.COMMENT_EXPR; }


    /**
     * Determines if the given node is matched by this MatchExpr with
     * respect to the given context node.
     * @param node the node to determine a match for
     * @param context the Node which represents the current context
     * @param exprContext the ExprContext which has additional
     * information sometimes needed for evaluating XPath expressions
     * @return true if the given node is matched by this MatchExpr
     * @exception InvalidExprException when an invalid expression is
     * encountered during evaluation
    **/
    public boolean matches(Node node, Node context, ExprContext exprContext)
        throws InvalidExprException
    {
        if (node == null) return false;
        return (node.getNodeType() == Node.COMMENT_NODE);
    } //-- matches

} //-- CommentExpr
