/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * $Id$
 */
package com.kvisco.xpath;

import org.w3c.dom.*;

/**
 * Simple interface which provides the access method signatures
 * required for retrieving context information needed for
 * the evaluation of XPath Expressions. Context information
 * consists of things such as the current context node, and
 * context node set
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
 * @version $Revision$ $Date$
**/
public interface ExprContext {


      //------------------/
     //- Public Methods -/
    //------------------/
    
    /**
     * Returns the current context NodeSet
     * @return the current context NodeSet
    **/
    public NodeSet getNodeSet();
    
    /**
     * Returns the document order of the given node
     * @return the document order of the given node
    **/
    public int[] getDocumentOrder(Node node);
    
    /**
     * Returns the ExprResult bound to the given name
     * @param name the name of the ExprResult to return
     * @return the ExprResult bound to the given name
    **/
    public ExprResult getVariable(String name);
    
    /**
     * Finds the parent of a given Node. Since certain
     * Nodes in DOM level 1 do not have parents (theoretically)
     * we need a way to find the parent of any node (mainly
     * attribute nodes).
     * @param node the Node to find the parent of
     * @return the parent of the given node
    **/
    public Node findParent(Node node);
    
    /**
     * Adds the given NodeSet set to the top of the NodeSet stack
     * @param nodeSet the NodeSet to put on the top of the Context NodeSet
     * stack
    **/
    public void pushNodeSet(NodeSet nodeSet);
    
    /**
     * Removes the top NodeSet from the NodeSet stack
     * @return the NodeSet that was "popped" off the top of the NodeSet stack
    ***/
    public NodeSet popNodeSet();
       
    /**
     * Returns a call to the Function that has the given name. This method
     * is used for the XPath Extension Functions.
     * @return the FunctionCall for the Function with the given name
    **/
    public FunctionCall resolveFunctionCall(String functionName);
    
    /**
     * Returns the Node that is associated with the given Id.
     * @return the Node that is associated with the given Id, or null
     * if no Node has been found
    **/
    public Node resolveId(String id);
    
        
        
        
} //-- ExprContext