/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 */
 
package com.kvisco.xpath;

/**
 * A class for representing function call
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
**/
public abstract class FunctionCall extends ParamList implements Expr {
    
    public static final String INVALID_NUMBER_PARAMS = 
        "invalid number of parameters for function: ";
        
    public static final String INVALID_RESULT =
        "unexpected result for function: ";
        
    private static String START_PARAMLIST = "(";
    private static String END_PARAMLIST   = ")";
    private static String EMPTY_PARAMLIST = "()";
    private static String PARAMETER_SEP   = ",";
    
    String name = "undefined";
    
    public FunctionCall(String name) {
        this.name = name;
    } //-- FunctionCall
    
    /**
     * Returns the type of Expr this Expr represents
     * @return the type of Expr this Expr represents
    **/
    public short getExprType() {
        return Expr.PRIMARY;
    } //-- getExprType
    
    
    /**
     * Returns the name of this function call
     * @return the name of this function call
    **/
    public String getFunctionName() {
        return this.name;
    } //-- getFunctionName
    
    /**
     * Returns the String representation of this FunctionCall
     * @return the String representation of this FunctionCall
    **/
    public String toString() {
        StringBuffer sb = new StringBuffer(getFunctionName());
        sb.append(START_PARAMLIST);
        for (int i = 0; i < getParameterCount(); i++) {
            if (i > 0) sb.append(PARAMETER_SEP);
            sb.append( getParameter(i));
        }
        sb.append(END_PARAMLIST);
        return sb.toString();
    } //-- toString
    
} //-- FunctionCall