/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * $Id$
 */

package com.kvisco.xpath;

import org.w3c.dom.*;

/**
 * A utility class to handle common XPath functions such as 
 * obtaining the value of a Node.
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
 * @version $Revision$ $Date$
**/
public class NodeUtils {

    /**
     * 
    **/
    private NodeUtils() {
        super();
    } //-- NodeUtils
    
    /**
	 * Returns the String value of a DOM Node.
	 * @return the String value of a DOM Node.
	 * @see org.w3c.dom.Node
	**/
    public static String getNodeValue(Node node) {
        if (node == null) return "";
        switch (node.getNodeType()) {
            
            case Node.DOCUMENT_NODE:
                return getNodeValue(((Document)node).getDocumentElement());
            case Node.DOCUMENT_FRAGMENT_NODE:
            {
                StringBuffer sb = new StringBuffer();
                NodeList nl = node.getChildNodes();
                for (int i = 0; i < nl.getLength(); i++) {
                    sb.append(getNodeValue(nl.item(i)));
                }
                return sb.toString();
            }
            // elements
            case Node.ELEMENT_NODE:
            {
                NodeList list = node.getChildNodes();
                Node child;
                int size = list.getLength();
                StringBuffer sb = new StringBuffer();
                for (int i = 0; i < size; i++) {
                    child = list.item(i);
                    switch(child.getNodeType()) {
                        case Node.TEXT_NODE:
                        case Node.CDATA_SECTION_NODE:
                            if (size == 1) return ((Text)child).getData();
                            else sb.append(((Text)child).getData());
                            break;
                        case Node.ELEMENT_NODE:
                            if (size == 1) return getNodeValue(child);
                            else sb.append(getNodeValue(child));
                            break;
                        default:
                            break;
                    }
                }
                return sb.toString();
            }
            // attributes
            case Node.ATTRIBUTE_NODE:
                return ((Attr)node).getValue();
            // Text and Character Data
            case Node.CDATA_SECTION_NODE:
            case Node.TEXT_NODE:
                return ((Text)node).getData();
            // Comments
            case Node.COMMENT_NODE:
                return ((Comment)node).getData();
            // Processing Instructions
            case Node.PROCESSING_INSTRUCTION_NODE:
                return ((ProcessingInstruction)node).getData();
            default:
                break;
        }
        return "";
    } //-- getNodeValue

}

