/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * $Id$
 */

package com.kvisco.xpath;

import org.w3c.dom.Node;

/**
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
 * @version $Revision$ $Date$
**/
public class PredicateExpr implements Expr {
    
    private Expr _expr = null;
    private PredicateExpr _next = null;

    /**
     * Creates a new PredicateExpr using the given Expr
    **/
    public PredicateExpr(Expr expr) {
        super();
        this._expr = expr;
    } //-- PredicateExpr
    
    /**
     * Evaluates this Expr using the given context Node and ExprContext
     * @param context the current context Node
     * @param exprContext the ExprContext which has additional
     * information sometimes needed for evaluating XPath expressions
     * @return the ExprResult
     * @exception InvalidExprException when an invalid expression is
     * encountered during evaluation
    **/
    public ExprResult evaluate(Node context, ExprContext exprContext)
        throws InvalidExprException
    {
        if (_expr == null) return new BooleanResult(false);
        return _expr.evaluate(context, exprContext);
    } //-- evaluate

    /**
     * Returns the type of Expr this Expr represents
     * @return the type of Expr this Expr represents
    **/
    public short getExprType() {
        return Expr.BOOLEAN;
    }
    
    /**
     * Returns the next expr in this PredicateExpr
     * @returns the next expr in this PredicateExpr
    **/
    public PredicateExpr getNext() {
        return _next;
    } //-- getNext
    
    public boolean hasNext() {
        return (_next != null);
    }
        
    public void setNext(PredicateExpr expr) {
        this._next = expr;
    }
    
    public String toString() {
        return toString(null);
    }
    
    private String toString(StringBuffer sb) {
        if (sb == null) sb = new StringBuffer();
        if (_expr != null) {
            sb.append('[');
            sb.append(_expr.toString());
            sb.append(']');
            if (_next != null) _next.toString(sb);
        }
        return sb.toString();
    } //-- toString
    
} //-- Predicate