/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 */
package com.kvisco.xpath;

import org.w3c.dom.*;

/**
 * Represents an XPath Variable
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
**/
public class Variable {

    private ExprResult _exprResult = null;
    private String _name = null;
    
      //----------------/
     //- Constructors -/
    //----------------/
    
    /**
     * Creates a new Variable of the given type
     * @param name the name of the Variable
    **/
    public Variable(String name) {
        this._name = name;
    } //-- Variable
    
    public Variable(String name, ExprResult value) {
        this._name = null;
        this._exprResult = value;
    } //-- Variable

    /**
     * Returns the name of this Variable
     * @return the name of this Variable
    **/
    public String getName() {
        return _name;
    } //-- getName
    
    /**
     * Returns the ExprResult that has been bound to this Variable
     * @return the ExprResult that has been bound to this Variable
    **/
    public ExprResult getValue() {
        return this._exprResult;
    }
    
    /**
     * Binds the given ExprResult to this Variable
     * @param exprResult the value of this Variable
    **/
    public void setValue(ExprResult exprResult) {
        this._exprResult = exprResult;
    } //-- setValue
    
    /**
     * The String representation of this Variable, which is
     * simply the variable name
     * @return the String representation of this Variable
    **/
    public String toString() {
        return getName();
    }
    
} //-- Variable