/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * $Id$
 */
package com.kvisco.xpath;

import java.util.Hashtable;


/**
 * This class represents a set xpath variables
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
 * @version $Revision$ $Date$
**/
public class VariableSet {
    
    private Hashtable _variables = null;
    private VariableSet _variableSet = null;
    
    public VariableSet() {
        super();
        _variables = new Hashtable();
    } //-- VariableSet
    
    public VariableSet(int size) {
        super();
        _variables = new Hashtable(size);
        
    } //-- VariableSet
    
    public VariableSet(VariableSet variableSet) {
        this();
        _variableSet = variableSet;
    } //-- VariableScope
    
    /** 
     *
    **/
    public VariableSet(int size, VariableSet variableSet) {
        this(size);
        this._variableSet = variableSet;
    }
    
    /**
     * Adds the given Variable to this VariableSet
     * @param variable the Variable to add to this VariableSet
    **/
    public void add(Variable variable) {
        _variables.put(variable.getName(), variable);
    } //-- add

    /**
     * Returns the value of the Variable associated with the given name
     * @param name the name of the Variable to search for
     * @return the value of the Variable associated with the given name
    **/
    public ExprResult getValue(String name) {
        if (name == null) return null;
        Variable var = get(name);
        if (var != null) return var.getValue();
        return null;
    } //-- getValue(String)
    
    /**
     * Returns the Variable associated with the given name
     * @param name the name of the Variable to search for
     * @return the Variable associated with the given name
    **/
    public Variable get(String name) {
        if (name == null) return null;
        Variable var = (Variable)_variables.get(name);
        if ((var == null)&& (_variableSet != null)) {
            var = _variableSet.get(name);
        }
        return var;        
    } //-- get(String)
    
    /**
     * Removes the variable binding for the given name
     * @param the name of the Variable to search for
     * @return the Variable that was removed
    **/
    public Variable remove(String name) {
        if (name == null) return null;
        return (Variable)_variables.remove(name);
    }
    
    public void setSuperSet(VariableSet variableSet) {
        this._variableSet = variableSet;
    }
    
} //-- VariableSet