/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * 
 */
package com.kvisco.xpath.functions;

import org.w3c.dom.Node;

import com.kvisco.xpath.*;

/**
 * A class for representing function call
 * @author Keith Visco (kvisco@ziplink.net)
**/
public class ExtensionFunctionCall extends FunctionCall {
        
    public static final String FUNCTION_NOT_DEFINED =
        "The following function has not been defined: ";
        
    public ExtensionFunctionCall(String name) {
        super(name);
    } //-- ExtensionFunctionCall
    
    
    /**
     * Evaluates this Expr using the given context Node and ExprContext
     * @param context the current context Node
     * @param exprContext the ExprContext which has additional
     * information sometimes needed for evaluating XPath expressions
     * @return the ExprResult
     * @exception InvalidExprException when an invalid expression is
     * encountered during evaluation
    **/
    public ExprResult evaluate(Node context, ExprContext exprContext)
        throws InvalidExprException 
    {
        
        String fnName = getFunctionName();
        FunctionCall fnCall = exprContext.resolveFunctionCall(fnName);
        if (fnCall == null) {
            return new StringResult(FUNCTION_NOT_DEFINED+fnName);
        }
        
        //fnCall.addExprParameter(Expr)
        return fnCall.evaluate(context, exprContext);
    } //-- evaluate
    
} //-- ExtensionFunctionCall