/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * 
 */

package com.kvisco.xpath.functions;

import com.kvisco.xpath.*;

import java.util.StringTokenizer;

import org.w3c.dom.*;

/**
 * This class represents an Id() function call
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
**/
public class IdRefFunctionCall extends FunctionCall {
    
    
    private static final String IDREF = "idref";

      //----------------/
     //- Constructors -/
    //----------------/
    
    /**
     * Creates an IdFunctionCall
    **/
    public IdRefFunctionCall() {
        super(IDREF);
    } //-- IdRefFunctionCall
    
    
    /**
     * Evaluates this Expr using the given context Node and ExprContext
     * @param context the current context Node
     * @param exprContext the ExprContext which has additional
     * information sometimes needed for evaluating XPath expressions
     * environment
     * @return the ExprResult
     * @exception InvalidExprException when an invalid expression is
     * encountered during evaluation
    **/
    public ExprResult evaluate(Node context, ExprContext exprContext)
        throws InvalidExprException 
    {
        NodeSet nodeSet = new NodeSet();
        
        Node tmpNode;
        
        if (getParameterCount() == 1) {
            Expr expr = getParameter(0);
            
            StringBuffer ids = new StringBuffer();
            
            ExprResult exprResult = expr.evaluate(context, exprContext);
            if (exprResult.getResultType() == ExprResult.NODE_SET) {
                NodeSet nodes = (NodeSet)exprResult;
                for (int i = 0; i < nodes.size(); i++) {
                    ids.append(' ');
                    ids.append(NodeUtils.getNodeValue(nodes.get(i)));
                }
            }
            else {
                throw new InvalidExprException
                    ("invalid parameter for idref() function ->"+expr);
            }
            
            StringTokenizer st = new StringTokenizer(ids.toString());
            while (st.hasMoreTokens()) {
                tmpNode = (Element)exprContext.resolveId(st.nextToken());
                if (tmpNode != null) nodeSet.add(tmpNode);
            }
        }
                    
        return nodeSet;
    } //-- evaluate
    
} //-- IdFunctionCall