/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * $Id$
 */

package com.kvisco.xpath.functions;

import com.kvisco.xpath.*;
import org.w3c.dom.Node;

/**
 * A class that represents the following FunctionCalls:<BR /> 
 * number(); floor(); round(); ceiling();
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
 * @version $Revision$ $Date$
**/
public class NumberFunctionCall extends FunctionCall {
    
    public static final short NUMBER   = 0;
    public static final short ROUND    = 1;
    public static final short FLOOR    = 2;
    public static final short CEILING  = 3;
    
    short functionType = NUMBER;
    
    
    /**
     * Creates a new NumberFunctionCall
    **/
    public NumberFunctionCall() {
        super(Names.NUMBER_FN);
    } //-- NumberFunctionCall
    
    /**
     * Creates a new NumberFunctionCall using the given type
    **/
    public NumberFunctionCall(short type) {
        super(NumberFunctionCall.getFunctionName(type));
        this.functionType = type;
    } //-- NumberFunctionCall
    
    /**
     * Evaluates this Expr using the given context Node and ExprContext
     * @param context the current context Node
     * @param exprContext the ExprContext which has additional
     * information sometimes needed for evaluating XPath expressions
     * @return the ExprResult
     * @exception InvalidExprException when an invalid expression is
     * encountered during evaluation
    **/
    public ExprResult evaluate(Node context, ExprContext exprContext)
        throws InvalidExprException
    {
        
        
        if (getParameterCount() != 1)
            throw new InvalidExprException(INVALID_NUMBER_PARAMS+this);
            
        Expr expr = getParameter(0);
        if (expr != null)  {
            
            double value = expr.evaluate(context, exprContext).numberValue();
            
            switch (functionType) {
                case FLOOR:
                    value = Math.floor(value);
                    break;
                case ROUND:
                    value = Math.round(value);
                    break;
                case CEILING:
                    value = Math.ceil(value);
                    break;
                default: //-- NUMBER
                    break;
            }
            return new NumberResult(value);
        }
        return new NumberResult(Double.NaN);
    } //-- evaluate
    
    private static String getFunctionName(short type) {
        switch (type) {
            case FLOOR:
                return Names.FLOOR_FN;
            case ROUND:
                return Names.ROUND_FN;
            case CEILING:
                return Names.CEILING_FN;
            default:
                return Names.NUMBER_FN;
        }
    } //-- getFunctionName
    
} //-- NumberFunctionCall