/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 */

package com.kvisco.xpath.functions;

import com.kvisco.xpath.*;
import org.w3c.dom.Node;

/**
 * A implementation of the "translate" function call
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
**/
public class Translate extends FunctionCall {
    
    private static final String TRANSLATE = "translate";
    
    /**
     * Creates a new Translate FunctionCall
    **/
    public Translate() {
        super(TRANSLATE);
    } //-- Translate
    
    /**
     * Evaluates this Expr using the given context Node and ExprContext
     * @param context the current context Node
     * @param exprContext the ExprContext which has additional
     * information sometimes needed for evaluating XPath expressions
     * environment
     * @return the ExprResult
     * @exception InvalidExprException when an invalid expression is
     * encountered during evaluation
    **/
    public ExprResult evaluate(Node context, ExprContext exprContext)
        throws InvalidExprException
    {
        
        if (getParameterCount() != 3)
            throw new InvalidExprException(INVALID_NUMBER_PARAMS+this);
            
        ExprResult r1 = (getParameter(0)).evaluate(context, exprContext);
        ExprResult r2 = (getParameter(1)).evaluate(context, exprContext);
        ExprResult r3 = (getParameter(2)).evaluate(context, exprContext);
        
        String str1 = StringExpr.toStringResult(r1).getValue();
        String str2 = StringExpr.toStringResult(r2).getValue();
        String str3 = StringExpr.toStringResult(r3).getValue();
            
        StringBuffer result = new StringBuffer();
        
        char[] xchars = str1.toCharArray();
        
        for (int i = 0; i < xchars.length; i++) {
            int idx = str2.indexOf(xchars[i]);
            if (idx >= 0) {
                char nchar = str3.charAt(idx);
                if (nchar != -1) xchars[i] = nchar;
            }
        }
        
        return new StringResult( new String(xchars));
    } //-- evaluate
    
} //-- Translate

