/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The software is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by 
 * you as a result of using the software. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or 
 * lost profits even if the Copyright owner has been advised of the 
 * possibility of their occurrence.  
 */
package com.kvisco.xsl;

import org.w3c.dom.*;

import com.kvisco.xpath.InvalidExprException;
import com.kvisco.xpath.BooleanResult;
import com.kvisco.xpath.ExprContext;

/**
 * Represents a an interface for conditional based xsl elements
 * such as xsl:if and xsl:choose{xsl:when}
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
**/
public interface Conditional {
        
      //------------------/
     //- Public Methods -/
    //------------------/
    
    /**
     * Evaluates this Expr using the given context Node and ExprContext
     * @param context the current context Node
     * @param exprContext the ExprContext which has additional
     * information sometimes needed for evaluating XPath expressions
     * @return the ExprResult
     * @exception InvalidExprException when an invalid expression is
     * encountered during evaluation
    **/
    public BooleanResult evaluate(Node context, ExprContext exprContext)
        throws InvalidExprException;
    
        

} //-- Conditional