/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * $Id$
 */

package com.kvisco.xsl.functions;

import com.kvisco.xsl.ProcessorState;
import com.kvisco.xpath.*;
import com.kvisco.util.*;
import com.kvisco.xml.parser.DOMPackage;

import com.kvisco.net.URIUtils;

import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.io.StringWriter;

import org.w3c.dom.Node;
import org.w3c.dom.Document;


/**
 * A class that represents the XSL document() function call
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
 * @version $Revision$ $Date$
**/
public class DocumentFunctionCall extends FunctionCall {
    
    private ProcessorState ps = null;
    
    /**
     * Creates a new Document() Function Call
    **/
    public DocumentFunctionCall(ProcessorState ps) {
        super(Names.DOCUMENT_FN);
        this.ps = ps;
    } //-- DocumentFunctionCall
    
    /**
     * Evaluates this Expr using the given context Node and ExprContext
     * @param context the current context Node
     * @param exprContext the ExprContext which has additional
     * information sometimes needed for evaluating XPath expressions
     * environment
     * @return the ExprResult
     * @exception InvalidExprException when an invalid expression is
     * encountered during evaluation
    **/
    public ExprResult evaluate(Node context, ExprContext exprContext)
        throws InvalidExprException
    {
        
        int paramCount = getParameterCount();
        
        if ((paramCount < 1) || (paramCount > 2))
            throw new InvalidExprException(INVALID_NUMBER_PARAMS+this);
            
       
        ExprResult res1 = getParameter(0).evaluate(context, exprContext);
        //ExprResult res2 =  getParameter(1).evaluate(context, exprContext);
        
        NodeSet nodeSet = new NodeSet();
        
        switch (res1.getResultType()) {
            case ExprResult.NODE_SET:
                NodeSet nodes = (NodeSet)res1;
                for (int i = 0; i < nodes.size(); i++) {
                    String href = NodeUtils.getNodeValue(nodes.get(i));
                    Document doc = getDocument(href);
                    if (doc != null) nodeSet.add(doc);
                }
                break;
            default:
                String href = StringExpr.toStringResult(res1).toString();
                Document doc = getDocument(href);
                if (doc != null) nodeSet.add(doc);
                break;
        }
        return nodeSet;
    } //-- evaluate
    
    private Document getDocument(String href) {
        
        if ((href == null) || (href.length() == 0))
            href = ps.getStylesheetHref();
            
        InputStream inStream = null;
        try {
            inStream = URIUtils.getInputStream(href, "");
        }
        catch(Exception ex) {
            //-- add error message
            return null;
        }
        InputStreamReader isReader = new InputStreamReader(inStream);
        DOMPackage  domPackage  = ps.getDOMPackage();
        //PrintWriter pw = new PrintWriter( new StringWriter() );
        PrintWriter pw = new PrintWriter( System.out, true );
        return domPackage.readDocument(isReader, href, pw);
        
    }
} //-- DocumentFunctionCall