/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * $Id$ 
 */
package com.kvisco.xsl.functions;

import org.w3c.dom.Node;

import com.kvisco.xsl.*;
import com.kvisco.util.List;
import com.kvisco.xml.XMLUtil;

import com.kvisco.xpath.*;

/**
 * A class for representing extension function calls
 * @author <a href="kvisco@ziplink.net">Keith Visco</a>
 * @version $Revision$ $Date$
**/
public class ExtensionFunctionCall extends FunctionCall {
        
    public static final String FUNCTION_NOT_DEFINED =
        "The following function has not been defined: ";
        
    
    private ProcessorState ps = null;
    
    /**
     *
    **/
    public ExtensionFunctionCall(String name, ProcessorState ps) {
        super(name);
        this.ps = ps;
    } //-- ExtensionFunctionCall
    
    
    /**
     * Evaluates this Expr using the given context Node and ExprContext
     * @param context the current context Node
     * @param exprContext the ExprContext which has additional
     * information sometimes needed for evaluating XPath expressions
     * @return the ExprResult
     * @exception InvalidExprException when an invalid expression is
     * encountered during evaluation
    **/
    public ExprResult evaluate(Node context, ExprContext exprContext)
        throws InvalidExprException 
    {
        
        String qname = getFunctionName();
        String ns    = XMLUtil.getNameSpace(qname);
        String name  = XMLUtil.getLocalPart(qname);
        
        if (ns.length() == 0) ns = null;
        
        ScriptHandler sh = ps.getScriptHandler(name, ns);
        
        if (sh == null)
            return new StringResult(FUNCTION_NOT_DEFINED+qname);
            
        int paramCount = getParameterCount();
        Object[] args = new Object[paramCount];
        
        //-- evaluate arguments
        for (int i = 0; i < paramCount; i++) {
            Expr expr = getParameter(i);
            ExprResult exprResult = expr.evaluate(context, ps);
            args[i] = exprResult.toJavaObject();
        }
        
        Object obj = sh.call(name, args, ns);
        return new StringResult(obj.toString());
    } //-- evaluate
    
    /**
     * Returns the namespace that this function call is in
    **/
    public String getNameSpace() {
        return XMLUtil.getNameSpace(getFunctionName());
    } //-- getNameSpace
    
} //-- ExtensionFunctionCall