/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * 
 */

package com.kvisco.xsl.functions;

import com.kvisco.xpath.*;
import com.kvisco.xsl.ProcessorState;
import org.w3c.dom.Node;

/**
 *
 * @author <a href="kvisco@ziplink.net">Keith Visco</a>
 * @version $Revision$ $Date$
**/
public class GenerateIDFunctionCall extends FunctionCall {
    
    private ProcessorState ps = null;
    
    /**
     * Creates a new GenerateIDFunctionCall
    **/
    public GenerateIDFunctionCall(ProcessorState ps) {
        super(Names.GENERATE_ID_FN);
        this.ps = ps;
    } //-- GenerateIDFunctionCall
    
    /**
     * Evaluates this Expr using the given context Node and ExprContext
     * @param context the current context Node
     * @param exprContext the ExprContext which has additional
     * information sometimes needed for evaluating XPath expressions
     * environment
     * @return the ExprResult
     * @exception InvalidExprException when an invalid expression is
     * encountered during evaluation
    **/
    public ExprResult evaluate(Node context, ExprContext exprContext)
        throws InvalidExprException
    {
        
        Node node = context;
        if (getParameterCount() == 1) {
            Expr expr = getParameter(0);
            ExprResult exprResult = expr.evaluate(context, exprContext);
            if (exprResult.getResultType() == ExprResult.NODE_SET) {
                NodeSet nodeSet = (NodeSet)exprResult;
                if (nodeSet.size() == 0) {
                    return new StringResult("");
                }
                else node = nodeSet.get(0);
            }
            //-- need to add ErrResult
            else {
                StringBuffer errMsg 
                    = new StringBuffer("InvalidParameterType:");
                errMsg.append(" expecting NodeSet as parameter to: ");
                errMsg.append(this.toString());
                return new StringResult(errMsg.toString());
            }
        }
        return new StringResult( ps.generateId(node) );
    } //-- evaluate
    
} //-- GenerateIDFunctionCall