/*
 * (C) Copyright Keith Visco 1999  All rights reserved.
 *
 * The contents of this file are released under an Open Source 
 * Definition (OSD) compliant license; you may not use this file 
 * execpt in compliance with the license. Please see license.txt, 
 * distributed with this file. You may also obtain a copy of the
 * license at http://www.clc-marketing.com/xslp/license.txt
 *
 * The program is provided "as is" without any warranty express or
 * implied, including the warranty of non-infringement and the implied
 * warranties of merchantibility and fitness for a particular purpose.
 * The Copyright owner will not be liable for any damages suffered by
 * you as a result of using the Program. In no event will the Copyright
 * owner be liable for any special, indirect or consequential damages or
 * lost profits even if the Copyright owner has been advised of the
 * possibility of their occurrence.
 *
 * $Id$
 */

package com.kvisco.xsl.functions;

import com.kvisco.xsl.ProcessorState;
import com.kvisco.xpath.*;
import org.w3c.dom.Node;
import com.kvisco.xml.XMLUtil;

/**
 * A implementation of the "system-property" function call
 * @author <a href="mailto:kvisco@ziplink.net">Keith Visco</a>
 * @version $Revision$ $Date$
**/
public class SystemFunctionCall extends FunctionCall {
    
    public static final short SYSTEM_PROPERTY    = 1;
    public static final short FUNCTION_AVAILABLE = 2;
    
    private short fType = SYSTEM_PROPERTY;
    
    private ProcessorState ps = null;
    
    /**
     * Creates a new SystemFunctionCall using the default
     * function type (system-property())
    **/
    public SystemFunctionCall(ProcessorState ps) {
        super(Names.SYSTEM_PROPERTY_FN);
        this.ps = ps;
    } //-- SystemFunctionCall
    
    /**
     * Creates a new SystemFunctionCall 
    **/
    public SystemFunctionCall(ProcessorState ps, short type) {
        super(getFunctionName(type));
        this.fType = type;
        this.ps = ps;
    } //-- SystemFunctionCall
    
    /**
     * Evaluates this Expr using the given context Node and ExprContext
     * @param context the current context Node
     * @param exprContext the ExprContext which has additional
     * information sometimes needed for evaluating XPath expressions
     * environment
     * @return the ExprResult
     * @exception InvalidExprException when an invalid expression is
     * encountered during evaluation
    **/
    public ExprResult evaluate(Node context, ExprContext exprContext)
        throws InvalidExprException
    {
        
        if (getParameterCount() != 1)
            throw new InvalidExprException(INVALID_NUMBER_PARAMS+this);
            
        Expr expr = getParameter(0);
        
        StringResult strResult = 
            StringExpr.toStringResult(expr.evaluate(context, exprContext));
            
            
        String paramStr = strResult.getValue();
        
        if (fType == FUNCTION_AVAILABLE) {
            String ns = XMLUtil.getNameSpace(paramStr);
            if (ns.length() == 0) ns = null;
            String name = XMLUtil.getLocalPart(paramStr);
            return new BooleanResult(ps.getScriptHandler(name, ns) != null);
        }
        else //-- SystemProperty 
            return new StringResult(ps.getProperty(paramStr));
        
    } //-- evaluate
    
    
    private static String getFunctionName(short type) {
        if (type == FUNCTION_AVAILABLE)
            return Names.FUNCTION_AVAILABLE_FN;
        else 
            return Names.SYSTEM_PROPERTY_FN;
    } //-- getFunctionName
    
} //-- SystemFunctionCall

